@@ -27,7 +27,6 @@
 
 static gchar *desc_file = NULL;
 static gchar *output_file = NULL;
-static gchar *fts_properties_file = NULL;
 static gchar *explanation_file = NULL;
 
 static GOptionEntry   entries[] = {
@@ -39,10 +38,6 @@ static GOptionEntry   entries[] = {
 	  "File to write the output (default stdout)",
 	  NULL
 	},
-	{ "fts", 'f', 0, G_OPTION_ARG_FILENAME, &fts_properties_file,
-	  "Output file listing the full text indexed properties",
-	  NULL
-	},
 	{ "explanation", 'e', 0, G_OPTION_ARG_FILENAME, &explanation_file,
 	  "Verbosy explanation file in HTML format to include in the webpage",
 	  NULL
@@ -59,7 +54,6 @@ main (gint argc, gchar **argv)
 	gchar *ttl_file = NULL;
 	gchar *dirname = NULL;
 	FILE *f = NULL;
-	FILE *fts = NULL;
 
 	/* Translators: this messagge will apper immediately after the  */
 	/* usage string - Usage: COMMAND [OPTION]... <THIS_MESSAGE>     */
@@ -91,10 +85,6 @@ main (gint argc, gchar **argv)
 	}
 	g_assert (f != NULL);
 
-	if (fts_properties_file) {
-		fts = fopen (fts_properties_file, "a");
-	} 
-
 	description = ttl_loader_load_description (desc_file);
 
 	dirname = g_path_get_dirname (desc_file);
@@ -106,7 +96,7 @@ main (gint argc, gchar **argv)
 	g_free (ttl_file);
 	g_free (dirname);
 
-	ttl_sgml_print (description, ontology, f, fts, explanation_file);
+	ttl_sgml_print (description, ontology, f, explanation_file);
 
 	ttl_loader_free_ontology (ontology);
 	ttl_loader_free_description (description);
@@ -115,9 +105,5 @@ main (gint argc, gchar **argv)
 
 	fclose (f);
 
-	if (fts) {
-		fclose (fts);
-	}
-
 	return 0;
 }
