@@ -105,6 +105,7 @@ tracker_date_error_get_type (void)
     static const GEnumValue values[] = {
       { TRACKER_DATE_ERROR_OFFSET, "TRACKER_DATE_ERROR_OFFSET", "offset" },
       { TRACKER_DATE_ERROR_INVALID_ISO8601, "TRACKER_DATE_ERROR_INVALID_ISO8601", "invalid-iso8601" },
+      { TRACKER_DATE_ERROR_EMPTY, "TRACKER_DATE_ERROR_EMPTY", "empty" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = 
@@ -116,28 +117,6 @@ tracker_date_error_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "tracker-storage.h" */
-#include "tracker-storage.h"
-GType
-tracker_storage_type_get_type (void)
-{
-  static volatile gsize g_define_type_id__volatile = 0;
- 
-  if (g_once_init_enter (&g_define_type_id__volatile)) {
-    static const GFlagsValue values[] = {
-      { TRACKER_STORAGE_REMOVABLE, "TRACKER_STORAGE_REMOVABLE", "removable" },
-      { TRACKER_STORAGE_OPTICAL, "TRACKER_STORAGE_OPTICAL", "optical" },
-      { 0, NULL, NULL }
-    };
-    GType g_define_type_id = 
-       g_flags_register_static (g_intern_static_string ("TrackerStorageType"), values);
-      
-    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
-  }
-    
-  return g_define_type_id__volatile;
-}
-
 /* enumerations from "tracker-locale.h" */
 #include "tracker-locale.h"
 GType
