@@ -25,8 +25,8 @@
 
 #include <glib.h>
 
-#include <libtracker-common/tracker-language.h>
-#include <libtracker-common/tracker-ontologies.h>
+#include <libtracker-common/tracker-common.h>
+#include <libtracker-sparql/tracker-sparql.h>
 
 #include <libtracker-data/tracker-data-update.h>
 #include <libtracker-data/tracker-db-interface.h>
