@@ -88,6 +88,7 @@ TrackerProperty *   tracker_property_get_secondary_index     (TrackerProperty
 gboolean            tracker_property_get_fulltext_indexed    (TrackerProperty      *property);
 gboolean            tracker_property_get_multiple_values     (TrackerProperty      *property);
 gboolean            tracker_property_get_last_multiple_values(TrackerProperty      *property);
+gboolean            tracker_property_get_orig_multiple_values(TrackerProperty      *property);
 gboolean            tracker_property_get_transient           (TrackerProperty      *property);
 gboolean            tracker_property_get_is_new              (TrackerProperty      *property);
 gboolean            tracker_property_get_is_new_domain_index (TrackerProperty      *property,
@@ -95,6 +96,7 @@ gboolean            tracker_property_get_is_new_domain_index (TrackerProperty
 gboolean            tracker_property_get_writeback           (TrackerProperty      *property);
 const gchar *       tracker_property_get_default_value       (TrackerProperty      *property);
 gboolean            tracker_property_get_db_schema_changed   (TrackerProperty      *property);
+gboolean            tracker_property_get_cardinality_changed (TrackerProperty      *property);
 gboolean            tracker_property_get_is_inverse_functional_property
                                                              (TrackerProperty      *property);
 gboolean            tracker_property_get_force_journal       (TrackerProperty      *property);
@@ -124,6 +126,8 @@ void                tracker_property_set_multiple_values     (TrackerProperty
                                                               gboolean              value);
 void                tracker_property_set_last_multiple_values(TrackerProperty      *property,
                                                               gboolean              value);
+void                tracker_property_set_orig_multiple_values(TrackerProperty      *property,
+                                                              gboolean              value);
 void                tracker_property_set_transient           (TrackerProperty      *property,
                                                               gboolean              value);
 void                tracker_property_set_is_new              (TrackerProperty      *property,
@@ -137,6 +141,8 @@ void                tracker_property_set_default_value       (TrackerProperty
                                                               const gchar          *value);
 void                tracker_property_set_db_schema_changed   (TrackerProperty      *property,
                                                               gboolean              value);
+void                tracker_property_set_cardinality_changed (TrackerProperty      *property,
+                                                              gboolean              value);
 void                tracker_property_set_is_inverse_functional_property
                                                              (TrackerProperty      *property,
                                                               gboolean              value);
