@@ -141,10 +141,13 @@ void                  tracker_miner_fs_set_mtime_checking    (TrackerMinerFS  *f
 void                  tracker_miner_fs_set_initial_crawling  (TrackerMinerFS  *fs,
                                                               gboolean         do_initial_crawling);
 
+#ifndef TRACKER_DISABLE_DEPRECATED
 /* Setting locations to be processed in IndexingTree */
 void                  tracker_miner_fs_add_directory_without_parent
                                                              (TrackerMinerFS  *fs,
-                                                              GFile           *file);
+                                                              GFile           *file)
+                                                             G_GNUC_DEPRECATED;
+#endif
 
 void                  tracker_miner_fs_directory_add         (TrackerMinerFS  *fs,
                                                               GFile           *file,
