@@ -24,6 +24,7 @@
 #include <libtracker-miner/tracker-miner.h>
 
 #include "tracker-miner-files-index.h"
+#include "tracker-miner-files-peer-listener.h"
 
 
 static const gchar introspection_xml[] =
@@ -35,6 +36,9 @@ static const gchar introspection_xml[] =
   "    <method name='IndexFile'>"
   "      <arg type='s' name='file_uri' direction='in' />"
   "    </method>"
+  "    <method name='IndexFileForProcess'>"
+  "      <arg type='s' name='file_uri' direction='in' />"
+  "    </method>"
   "  </interface>"
   "</node>";
 
@@ -54,6 +58,7 @@ typedef struct {
 
 typedef struct {
 	TrackerMinerFiles *files_miner;
+	TrackerMinerFilesPeerListener *peer_listener;
 	GDBusConnection *d_connection;
 	GDBusNodeInfo *introspection_data;
 	guint registration_id;
@@ -161,6 +166,7 @@ index_finalize (GObject *object)
 		g_object_unref (priv->d_connection);
 	}
 
+	g_clear_object (&priv->peer_listener);
 	g_free (priv->full_name);
 	g_free (priv->full_path);
 
@@ -308,7 +314,8 @@ tracker_miner_files_index_reindex_mime_types (TrackerMinerFilesIndex *miner,
 static void
 handle_method_call_index_file (TrackerMinerFilesIndex *miner,
                                GDBusMethodInvocation  *invocation,
-                               GVariant               *parameters)
+                               GVariant               *parameters,
+                               gboolean                watch_source)
 {
 	TrackerMinerFilesIndexPrivate *priv;
 	TrackerDBusRequest *request;
@@ -365,7 +372,39 @@ handle_method_call_index_file (TrackerMinerFilesIndex *miner,
 #endif /* REQUIRE_LOCATION_IN_CONFIG */
 
 	if (is_dir) {
-		tracker_miner_fs_check_directory (TRACKER_MINER_FS (priv->files_miner), file, do_checks);
+		TrackerIndexingTree *indexing_tree;
+		TrackerDirectoryFlags flags;
+		gboolean is_watched, needs_watch = FALSE;
+		GFile *root;
+
+		indexing_tree = tracker_miner_fs_get_indexing_tree (TRACKER_MINER_FS (priv->files_miner));
+		root = tracker_indexing_tree_get_root (indexing_tree, file, &flags);
+
+		/* If the directory had already subscribers, we want to add all
+		 * further watches, so the directory survives as long as there's
+		 * watchers.
+		 */
+		is_watched = tracker_miner_files_peer_listener_is_file_watched (priv->peer_listener, file);
+
+		/* Check whether the requested dir is not over a (recursively)
+		 * watched directory already, in that case we don't add the
+		 * directory (nor add a watch if we're positive it comes from
+		 * config).
+		 */
+		if (!root || !(flags & TRACKER_DIRECTORY_FLAG_RECURSE)) {
+			tracker_indexing_tree_add (indexing_tree, file,
+			                           TRACKER_DIRECTORY_FLAG_RECURSE |
+			                           TRACKER_DIRECTORY_FLAG_PRIORITY |
+			                           TRACKER_DIRECTORY_FLAG_CHECK_MTIME |
+			                           TRACKER_DIRECTORY_FLAG_MONITOR);
+			needs_watch = TRUE;
+		}
+
+		if (watch_source && (is_watched || needs_watch)) {
+			tracker_miner_files_peer_listener_add_watch (priv->peer_listener,
+			                                             g_dbus_method_invocation_get_sender (invocation),
+			                                             file);
+		}
 	} else {
 		tracker_miner_fs_check_file (TRACKER_MINER_FS (priv->files_miner), file, do_checks);
 	}
@@ -394,12 +433,38 @@ handle_method_call (GDBusConnection       *connection,
 	if (g_strcmp0 (method_name, "ReindexMimeTypes") == 0) {
 		tracker_miner_files_index_reindex_mime_types (miner, invocation, parameters);
 	} else if (g_strcmp0 (method_name, "IndexFile") == 0) {
-		handle_method_call_index_file (miner, invocation, parameters);
+		handle_method_call_index_file (miner, invocation, parameters, FALSE);
+	} else if (g_strcmp0 (method_name, "IndexFileForProcess") == 0) {
+		handle_method_call_index_file (miner, invocation, parameters, TRUE);
 	} else {
 		g_assert_not_reached ();
 	}
 }
 
+static void
+peer_listener_unwatch_file (TrackerMinerFilesPeerListener *listener,
+                            GFile                         *file,
+                            gpointer                       user_data)
+{
+	TrackerMinerFilesIndexPrivate *priv;
+	TrackerIndexingTree *indexing_tree;
+
+	priv = TRACKER_MINER_FILES_INDEX_GET_PRIVATE (user_data);
+	indexing_tree = tracker_miner_fs_get_indexing_tree (TRACKER_MINER_FS (priv->files_miner));
+	tracker_indexing_tree_remove (indexing_tree, file);
+}
+
+static void
+indexing_tree_directory_remove (TrackerIndexingTree *indexing_tree,
+                                GFile               *file,
+                                gpointer             user_data)
+{
+	TrackerMinerFilesIndexPrivate *priv;
+
+	priv = TRACKER_MINER_FILES_INDEX_GET_PRIVATE (user_data);
+	tracker_miner_files_peer_listener_remove_file (priv->peer_listener, file);
+}
+
 static GVariant *
 handle_get_property (GDBusConnection  *connection,
                      const gchar      *sender,
@@ -441,6 +506,7 @@ tracker_miner_files_index_new (TrackerMinerFiles *miner_files)
 	GVariant *reply;
 	guint32 rval;
 	GError *error = NULL;
+	TrackerIndexingTree *indexing_tree;
 	GDBusInterfaceVTable interface_vtable = {
 		handle_method_call,
 		handle_get_property,
@@ -530,5 +596,13 @@ tracker_miner_files_index_new (TrackerMinerFiles *miner_files)
 
 	priv->full_path = full_path;
 
+	priv->peer_listener = tracker_miner_files_peer_listener_new (priv->d_connection);
+	g_signal_connect (priv->peer_listener, "unwatch-file",
+	                  G_CALLBACK (peer_listener_unwatch_file), miner);
+
+	indexing_tree = tracker_miner_fs_get_indexing_tree (TRACKER_MINER_FS (miner_files));
+	g_signal_connect (indexing_tree, "directory-removed",
+	                  G_CALLBACK (indexing_tree_directory_remove), miner);
+
 	return (TrackerMinerFilesIndex *) miner;
 }
