@@ -21,7 +21,7 @@
 
 #include <libtracker-common/tracker-dbus.h>
 #include <libtracker-sparql/tracker-sparql.h>
-#include <libtracker-miner/tracker-miner-dbus.h>
+#include <libtracker-miner/tracker-miner.h>
 
 #include "tracker-writeback-dispatcher.h"
 
