@@ -372,7 +372,7 @@ rdf_types_to_uris_cb (GObject      *object,
 		                            "<%s> a nfo:FileDataObject . "
 		                            "<%s> ?predicate ?object ; nie:url ?url . "
 		                            "?predicate tracker:writeback true . "
-		                            "FILTER (NOT EXISTS { GRAPH <"TRACKER_MINER_FS_GRAPH_URN"> "
+		                            "FILTER (NOT EXISTS { GRAPH <" TRACKER_OWN_GRAPH_URN "> "
 		                              "{ <%s> ?predicate ?object } }) } ",
 		                         subject, subject, subject, subject);
 
