@@ -60,7 +60,7 @@ def expandvars (variable):
 
 
 
-PREFIX = "/opt/gnome"
+PREFIX = "/home/carlos/Build/gnome"
 #
 # This raw variables are set by autotools without translating vars:
 #   E.G. bindir='${exec_prefix}/bin
@@ -78,7 +78,7 @@ DATADIR = os.path.normpath (expandvars (RAW_DATA_DIR))
 BINDIR = os.path.normpath (expandvars (RAW_BINDIR))
                             
 haveMaemo = ("#" == "")
-haveUpstart = ("" == "")
+haveUpstart = ("#" == "")
 disableJournal = ("#" == "")
 
 TEST_TMP_DIR = os.path.join (os.environ["HOME"], "tracker-tests")
